********************************************************************************
* Created by Giselle Kolenic, gkolenic@umich.edu, University of Michigan
* Last updated 02/13/2025
* Purpose: 2025 Stata Biostatistics and Epidemology Virtual Symposium TLF Creation
* Title: "Increase efficiency and reproducibility in clinical trial reporting with Stata tools"
********************************************************************************

********************************************************************************
*Section 1.0
*Get Started
********************************************************************************

*set working directory
cd "C:\Users\gkolenic\Desktop\Stata Symposium 2025"

*version control 
version 18.5

*data cutoff date
*update this every reporting period
local dcd="2025JAN24"

*DSMB meeting date
*update this every reporting period
local DSMB_MD="2025MAR01"

********************************************************************************
*Section 2.0
*Create Summary Statistics from Most Recent Data
********************************************************************************

*Section 2.1 *******************************************************************
*Figure 1 Creation *************************************************************


*Open the data
use Stata_Study_`dcd', clear

*Create a smaller dataset with only the needed elements
keep ID CSTDT SITE
save Figure1_`dcd'.dta, replace

*Consent Date -> Extract Month/Year
gen c_year=year(CSTDT)
gen c_month=month(CSTDT)
gen c_ym=ym(c_year, c_month)
format %tmMonth_CCYY c_ym

*Create a string variable for Month
gen c_month_str="January" if c_month==1
replace c_month_str="February" if c_month==2
replace c_month_str="March" if c_month==3
replace c_month_str="April" if c_month==4
replace c_month_str="May" if c_month==5
replace c_month_str="June" if c_month==6
replace c_month_str="July" if c_month==7
replace c_month_str="August" if c_month==8
replace c_month_str="September" if c_month==9
replace c_month_str="October" if c_month==10
replace c_month_str="November" if c_month==11
replace c_month_str="December" if c_month==12

*Generate a variable that is the number of consented participants overall 
gen N_CST=_N

*For each month/year, indicate the N consented
bysort c_ym: gen N_CST_ym=_N

*Tag each unique month/year
egen tag_ym=tag(c_ym)

*Keep only one row per month/year 
keep if tag_ym==1

*Create cumulative sum
gen cumulative=sum(N_CST_ym)

*Save the data 
save Figure1_`dcd'.dta, replace

*Create The Plot
twoway (line cumulative c_ym) ///
(scatter cumulative c_ym, mlab(cumulative) mlabcolor(black) mlabposition(12) mcolor(black)), ///
ytitle("Cumulative Number of Consented Participants") ///
xtitle("Month and Year") legend(off)
*Save 
graph save Figure1_Final_`dcd'.gph, replace
graph export Figure1_Final_`dcd'.png, replace 


*Section 2.2 *******************************************************************
*Summary Statistics for Table 1 ************************************************

*Open the data
use Stata_Study_`dcd', clear

*Create a smaller dataset with only the needed elements
keep ID CSTDT SITE
save Table1_`dcd'.dta, replace

*Consent Date -> Extract Month/Year
gen c_year=year(CSTDT)
gen c_month=month(CSTDT)
gen c_ym=ym(c_year, c_month)
format %tmMonth_CCYY c_ym

*Create a string variable for Month
gen c_month_str="January" if c_month==1
replace c_month_str="February" if c_month==2
replace c_month_str="March" if c_month==3
replace c_month_str="April" if c_month==4
replace c_month_str="May" if c_month==5
replace c_month_str="June" if c_month==6
replace c_month_str="July" if c_month==7
replace c_month_str="August" if c_month==8
replace c_month_str="September" if c_month==9
replace c_month_str="October" if c_month==10
replace c_month_str="November" if c_month==11
replace c_month_str="December" if c_month==12

*Generate a variable that is the number of consented participants overall 
gen N_CST=_N

*Generate a variable that is the number of consented participants by site 
bysort SITE: gen N_CST_site=_N

*For each month/year, indicate the N consented
bysort c_ym: gen N_CST_ym=_N

*For each month/year, indicate the % consented
gen Perc_CST_overall=N_CST_ym/N_CST

*For each month/year and site, indicate the N consented
bysort c_ym SITE: gen N_CST_ymsite=_N

*For each month/year, indicate the % consented
gen Perc_CST_site=N_CST_ymsite/N_CST_site

*Format n and percent for Table 1 - want a combination of "n (%)"
gen percent_symbol="%"
gen open="("
gen closed=")"
gen space=" "
*Overall
gen percent_int1=round(Perc_CST_overall*100)
egen percent_int2=concat(percent_int1 percent_symbol)
egen percent_int3=concat(open percent_int2 closed)
egen n_perc_overall=concat(N_CST_ym space percent_int3)
*Drop intermediate variables 
drop percent_int* 
*By Site
gen percent_int1=round(Perc_CST_site*100)
egen percent_int2=concat(percent_int1 percent_symbol)
egen percent_int3=concat(open percent_int2 closed)
egen n_perc_site=concat(N_CST_ymsite space percent_int3)
*Drop intermediate variables 
drop percent_int* Perc_CST_overall percent_symbol open closed space percent_int1 percent_int2 percent_int3

*Tag for month/year
egen tag_ym=tag(c_ym)

*Tag for month/year by site 
egen tag_ymsite=tag(SITE c_ym)

*save the update Table 1 data 
save Table1a_`dcd', replace

*Overall and Site Specific Tables
*Overall (Only) Table 1a
use Table1a_`dcd'.dta, clear
keep c_month_str c_year c_ym N_CST N_CST_ym n_perc_overall tag_ym
keep if tag_ym==1
drop tag_ym
save Table1b_overall_`dcd'.dta, replace
*Site Specific Table 1's
forvalues i=1/4 {
	use Table1a_`dcd'.dta, clear
	keep if SITE==`i'
	keep c_ym N_CST_site N_CST_ymsite n_perc_site tag_ymsite
	keep if tag_ymsite==1
	foreach var of varlist N_CST_site N_CST_ymsite n_perc_site {
		rename `var' `var'_`i'
	}
	drop tag_ymsite
	save Table1b_`i'_`dcd', replace
}

*Merge overall and site specific table to create final Table 1 
use Table1b_overall_`dcd'.dta, clear
forvalues i=1/4 {
	merge 1:1 c_ym using Table1b_`i'_`dcd'
	drop _merge
} 
save Table1_Final_`dcd'.dta, replace



*Section 2.3 *******************************************************************
*Summary Statistics for Table 2 ************************************************
*Categorical Variables

*Open the data
use Stata_Study_`dcd', clear

*Create a local macro with the categorical variables to summarize in Table 2
local demo SEX_d* RACE_d* ETHNIC_d*

*Close any open post files 
capture postclose Table2_`dcd'
*Set up the specifications for your post file
postfile Table2_`dcd' str50 variable str100 varlabel_data n N proportion using Table2_`dcd'.dta, replace
*Loop over the dummy/binary variables of interest (see demo macro above)
foreach var of varlist `demo' {
		*obtain the variable labels 
		local varlabel_data: variable label `var'
		*obtain the proportion & denominator for each dummy/binary variable 
		ci proportions `var'
		local proportion=r(proportion)
		local N=r(N)
		*obtain the numerator (n)
		ci proportions `var' if `var'==1
		local n=r(N)
*Drop the results from the loop into the post file (by calling up all the local macros from above) 
post Table2_`dcd' ("`var'") ("`varlabel_data'") (`n') (`N') (`proportion')
*End the loops
}
*Close the post file 
postclose Table2_`dcd'

*Open the Table2 results in Stata 
use Table2_`dcd'.dta, clear

*Replace missing with zero 
replace n=0 if n==.
replace N=0 if N==.

*Format percent for table - want a combination of "n (%)"
gen percent_symbol="%"
gen percent_int1=round(proportion*100)
egen percent_int2=concat(percent_int1 percent_symbol)
gen open="("
gen closed=")"
gen space=" "
egen percent_int3=concat(open percent_int2 closed)
egen n_percent=concat(n space percent_int3)
*drop intermediate variables 
drop percent_symbol percent_int* proportion open closed space n
*save the update Table 2 data 
save, replace

*Pull in labels for the final tables 
clear
import excel "Table2_Labels.xlsx", sheet("Sheet1") firstrow clear
save Table2_Labels.dta, replace

*Create Final Table 2 
use Table2_`dcd'.dta, clear
*Merge the labels into the table
merge 1:1 variable using Table2_Labels.dta
*Sort the table by the variable "order"
sort order
*Reorder the variables
order variable varlabel N n_percent
*Drop intermediate variables
drop varlabel_data order _merge
*Drop unecessary information 
replace variable=" " if varlabel!=""
*Save the final Table 2 
compress
save Table2_Final_`dcd'.dta, replace


*Section 2.4 *******************************************************************
*Listing 1 **********************************************
*Treatment-Emergent SAEs. Safety Population. 

*Open the data
use Stata_Study_AE_`dcd', clear

*Listing 1 includes only treatment emergent SAE
save Listing1_Final_`dcd'.dta, replace 

********************************************************************************
*Section 3.0
*Clean up folder 
********************************************************************************

*Erase intermediate data files
erase Table1a_`dcd'.dta 
erase Table1b_1_`dcd'.dta 
erase Table1b_2_`dcd'.dta 
erase Table1b_3_`dcd'.dta 
erase Table1b_4_`dcd'.dta 
erase Table1b_overall_`dcd'.dta
erase Table2_`dcd'.dta 
erase Figure1_`dcd'.dta 